@@ -5,9 +5,9 @@ from cytra.auth import AuthAppMixin
 
 class CytraAppBase(GongishApp):
     # Reserved CORS config
-    _cors_allow_methods: set = None
-    _cors_allow_headers: set = None
-    _cors_expose_headers: set = None
+    __cors_allow_methods__: set = set()
+    __cors_allow_headers__: set = set(("content-type",))
+    __cors_expose_headers__: set = set(("content-type",))
 
     @staticmethod
     def format_json(request, response, indent=None):
@@ -20,9 +20,7 @@ class CytraAppBase(GongishApp):
     __default_formatter__ = format_json
 
     def setup(self):
-        self._cors_allow_methods = set()
-        self._cors_allow_headers = set(("content-type",))
-        self._cors_expose_headers = set(("content-type",))
+        pass
 
     def shutdown(self):
         pass
