@@ -20,8 +20,8 @@ class AuthAppMixin:
         super().setup()
         if "auth" in self.config:
             self.auth = self.__authenticator__(app=self)
-            self._cors_allow_headers.update(("authorization",))
-            self._cors_expose_headers.update(("x-new-jwt-token",))
+            self.__cors_allow_headers__.update(("authorization",))
+            self.__cors_expose_headers__.update(("x-new-jwt-token",))
         else:
             self.auth = None
 
